bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.plates_multiplier
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: WrapToGaussianGammaISO.plates_multiplier